Struct yew_bootstrap::component::card::Card
source · pub struct Card { /* private fields */ }Expand description
Card component
Container for a Card, a component generally used for dynamic display of items in a grid pattern. Takes any item as child, but most often body items, image items, or a flush ListGroup.
See CardProps for a list of properties.
Examples
With header and footer text:
use yew::prelude::*;
use yew_bootstrap::component::card::*;
fn test() -> Html {
html! {
<Card>
<CardHeader>{"Card Head"}</CardHeader>
<CardBody>{"Body text"}</CardBody>
<CardFooter>{"Card Foot"}</CardFooter>
</Card>
}
}With a top image and image description, instead:
use yew::prelude::*;
use yew_bootstrap::component::card::*;
fn test() -> Html {
html! {
<Card>
<CardImage variant={ImageVariant::Top} src="imgsrc.jpg"/>
<CardBody>{"Image description"}</CardBody>
</Card>
}
}Setting the body property, everything is implicitly wrapped in a CardBody:
use yew::prelude::*;
use yew_bootstrap::component::card::*;
fn test() -> Html {
html! {
<Card body=true>
{"Body text, great for simple cards"}
</Card>
}
}Trait Implementations
sourceimpl BaseComponent for Cardwhere
Self: 'static,
impl BaseComponent for Cardwhere
Self: 'static,
type Properties = CardProps
type Properties = CardProps
The Component’s Properties.
sourcefn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
fn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
Updates component’s internal state.
sourcefn changed(
&mut self,
_ctx: &Context<Self>,
_old_props: &Self::Properties
) -> bool
fn changed( &mut self, _ctx: &Context<Self>, _old_props: &Self::Properties ) -> bool
React to changes of component properties.
sourcefn view(&self, ctx: &Context<Self>) -> HtmlResult
fn view(&self, ctx: &Context<Self>) -> HtmlResult
Returns a component layout to be rendered.
sourcefn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
fn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
Notified after a layout is rendered.
sourcefn prepare_state(&self) -> Option<String>
fn prepare_state(&self) -> Option<String>
Prepares the server-side state.
sourceimpl FunctionProvider for Card
impl FunctionProvider for Card
type Properties = CardProps
type Properties = CardProps
Properties for the Function Component.
sourcefn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult
fn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult