pub enum FormControlValidation {
None,
Valid(Option<AttrValue>),
Invalid(AttrValue),
}Expand description
Validation type for a form control, with feedback message
Variants
None
Form field has not been validated or nothing to show
Valid(Option<AttrValue>)
Valid validation with optional feedback message
Invalid(AttrValue)
Invalid validation with feedback message