pub struct BIFiles {
pub css: &'static str,
pub font_woff: &'static [u8],
pub font_woff2: &'static [u8],
pub license: &'static str,
}Expand description
Holds all bootstrap-icons data.
Intended use:
let BIFiles {css, font_woff, font_woff2, license} = BIFiles::FILES;(That way it will be an error if a file is added/removed.)
Fields
css: &'static strContents of the file bootstrap-icons.css.
font_woff: &'static [u8]Contents of the file fonts/bootstrap-icons.woff.
font_woff2: &'static [u8]Contents of the file fonts/bootstrap-icons.woff2.
license: &'static strContents of the file fonts/LICENSE.
Implementations
Sourceimpl BIFiles
impl BIFiles
Sourcepub const FILES: Self
pub const FILES: Self
All bootstrap-icons files.
Intended use:
let BIFiles {css, font_woff, font_woff2, license} = BIFiles::FILES;(That way it will be an error if a file is added/removed.)